Given a url, tries to find local proxy settings and GET the content of the GHO page.
get_gho_(url, verbose = options()$rgho.verbose, retry = options()$rgho.retry)get_gho(url, verbose = options()$rgho.verbose, retry = options()$rgho.retry)
the url to retrieve, given as a character string.
Verbose mode?
Maximum number of GET re-trials.
The result from GET.
The function re-tries failed attempts using exponential backoff with jitter.