Learn R Programming

rgho (version 2.0.2)

rgho: rgho: Access WHO Global Health Observatory Data From R

Description

Access WHO Global Health Observatory data from R via the Athena web service, an application program interface providing a simple query interface to the World Health Organization's data and statistics content.

Arguments

Package Options

  • rgho.verbose Should informations about the request be diplayed? Defaults to FALSE.

  • rgho.retry How many times the request should be retried? Defaults to 5.

  • rgho.memotime For how long should the results of a request be memoised, in seconds? Defaults to 3600.