Learn R Programming

rgho (version 0.2.3)

get_gho_: GET a GHO URL

Description

Given a url, tries to find local proxy settings and GET the content of the GHO page.

Usage

get_gho_(url, verbose = options()$rgho.verbose, retry = options()$rgho.retry)
get_gho(url, verbose = options()$rgho.verbose, retry = options()$rgho.retry)

Arguments

url
the url to retrieve, given as a character string.
verbose
Verbose mode?
retry
Maximum number of GET re-trials.

Value

The result from GET.

Details

The function re-tries failed attempts using exponential backoff with jitter.