Learn R Programming

rgho (version 0.1.0)

get_gho_: GET a GHO URL

Description

Given a url, tries to find local proxy settings and GET the content of the GHO page.

Usage

get_gho_(url, debug = FALSE, max_try = 5)
get_gho(url, debug = FALSE, max_try = 5)

Arguments

url
the url to retrieve, given as a character string.
debug
Print debugging messages?
max_try
Maximum number of get trials.

Value

The result from httr GET function.