Learn R Programming

rgho (version 0.0.1)

get_gho_: GET a GHO URL

Description

Given a url, tries to find local proxy settings and GET the content of the GHO page.

Usage

get_gho_(url)

get_gho(url)

Arguments

url
the url to retrieve, given as a character string.

Value

  • The result from httr GET function.